@@ -1,4 +1,4 @@
-package Zonemaster::Test::Address v1.0.0;
+package Zonemaster::Test::Address v1.0.1;
 
 use 5.14.2;
 use strict;
@@ -20,11 +20,11 @@ sub all {
     my ( $class, $zone ) = @_;
     my @results;
 
-    push @results, $class->address01( $zone );
-    push @results, $class->address02( $zone );
+    push @results, $class->address01( $zone ) if Zonemaster->config->should_run('address01');
+    push @results, $class->address02( $zone ) if Zonemaster->config->should_run('address02');
     # Perform ADDRESS03 if ADDRESS02 passed
     if ( any { $_->tag eq q{NAMESERVERS_IP_WITH_REVERSE} } @results ) {
-        push @results, $class->address03( $zone );
+        push @results, $class->address03( $zone ) if Zonemaster->config->should_run('address03');
     }
 
     return @results;
@@ -148,8 +148,16 @@ sub address02 {
         next if $ips{ $local_ns->address->short };
 
         my $reverse_ip_query = $local_ns->address->reverse_ip;
+
         my $p = Zonemaster::Recursor->recurse( $reverse_ip_query, q{PTR} );
 
+        # In case of Classless IN-ADDR.ARPA delegation, query returns
+        # CNAME records. A PTR query is done on the CNAME.
+        if ($p->rcode eq q{NOERROR} and $p->get_records( q{CNAME}, q{answer} ) ) {
+            my ( $cname ) = $p->get_records( q{CNAME}, q{answer} );
+            $p = Zonemaster::Recursor->recurse( $cname->cname, q{PTR} );
+        }
+
         if ( $p ) {
             if ( $p->rcode ne q{NOERROR} or not $p->get_records( q{PTR}, q{answer} ) ) {
                 push @results,
@@ -184,6 +192,7 @@ sub address02 {
 sub address03 {
     my ( $class, $zone ) = @_;
     my @results;
+    my $ptr_query;
 
     my %ips;
 
@@ -192,11 +201,20 @@ sub address03 {
         next if $ips{ $local_ns->address->short };
 
         my $reverse_ip_query = $local_ns->address->reverse_ip;
+        $ptr_query = $reverse_ip_query;
 
-        my $p = Zonemaster::Recursor->recurse( $reverse_ip_query, q{PTR} );
+        my $p = Zonemaster::Recursor->recurse( $ptr_query, q{PTR} );
+
+        # In case of Classless IN-ADDR.ARPA delegation, query returns
+        # CNAME records. A PTR query is done on the CNAME.
+        if ($p->rcode eq q{NOERROR} and $p->get_records( q{CNAME}, q{answer} ) ) {
+            my ( $cname ) = $p->get_records( q{CNAME}, q{answer} );
+            $ptr_query = $cname->cname;
+            $p = Zonemaster::Recursor->recurse( $ptr_query, q{PTR} );
+        }
 
         if ( $p ) {
-            my @ptr = $p->get_records_for_name( q{PTR}, $reverse_ip_query );
+            my @ptr = $p->get_records_for_name( q{PTR}, $ptr_query );
             if ( $p->rcode eq q{NOERROR} and scalar @ptr ) {
                 if ( none { name( $_->ptrdname ) eq $local_ns->name->string . q{.} } @ptr ) {
                     push @results,
