@@ -1,4 +1,4 @@
-package Zonemaster::Test::DNSSEC v1.0.1;
+package Zonemaster::Test::DNSSEC v1.0.2;
 
 ###
 ### This test module implements DNSSEC tests.
@@ -124,25 +124,25 @@ sub all {
     my ( $class, $zone ) = @_;
     my @results;
 
-    push @results, $class->dnssec01( $zone );
+    push @results, $class->dnssec01( $zone ) if Zonemaster->config->should_run('dnssec01');
     if ( none { $_->tag eq 'NO_DS' } @results ) {
-        push @results, $class->dnssec02( $zone );
-        push @results, $class->dnssec03( $zone );
-        push @results, $class->dnssec04( $zone );
-        push @results, $class->dnssec05( $zone );
-        push @results, $class->dnssec07( $zone );
-        if ( grep { $_->tag eq q{DNSKEY_BUT_NOT_DS} or $_->tag eq q{DNSKEY_AND_DS} } @results ) {
-            push @results, $class->dnssec06( $zone );
-        }
-        else {
-            push @results,
-              info( ADDITIONAL_DNSKEY_SKIPPED => {} );
-        }
-        push @results, $class->dnssec08( $zone );
-        push @results, $class->dnssec09( $zone );
-        push @results, $class->dnssec10( $zone );
-        push @results, $class->dnssec11( $zone );
+        push @results, $class->dnssec02( $zone ) if Zonemaster->config->should_run('dnssec02');
     }
+    push @results, $class->dnssec03( $zone ) if Zonemaster->config->should_run('dnssec03');
+    push @results, $class->dnssec04( $zone ) if Zonemaster->config->should_run('dnssec04');
+    push @results, $class->dnssec05( $zone ) if Zonemaster->config->should_run('dnssec05');
+    push @results, $class->dnssec07( $zone ) if Zonemaster->config->should_run('dnssec07');
+    if ( grep { $_->tag eq q{DNSKEY_BUT_NOT_DS} or $_->tag eq q{DNSKEY_AND_DS} } @results ) {
+        push @results, $class->dnssec06( $zone ) if Zonemaster->config->should_run('dnssec06');
+    }
+    else {
+        push @results,
+          info( ADDITIONAL_DNSKEY_SKIPPED => {} );
+    }
+    push @results, $class->dnssec08( $zone ) if Zonemaster->config->should_run('dnssec08');
+    push @results, $class->dnssec09( $zone ) if Zonemaster->config->should_run('dnssec09');
+    push @results, $class->dnssec10( $zone ) if Zonemaster->config->should_run('dnssec10');
+    push @results, $class->dnssec11( $zone ) if Zonemaster->config->should_run('dnssec11');
 
     return @results;
 } ## end sub all
@@ -1147,6 +1147,8 @@ sub dnssec11 {
     my %dnskey = map { $_->keytag => $_ } $dnskey_p->get_records_for_name( 'DNSKEY', $zone->name->string );
     my %rrsig  = map { $_->keytag => $_ } $dnskey_p->get_records_for_name( 'RRSIG',  $zone->name->string );
 
+    my $pass = 0;
+    my @fail;
     if ( scalar( keys %ds ) > 0 ) {
         foreach my $tag ( keys %ds ) {
             my $ds  = $ds{$tag};
@@ -1160,28 +1162,33 @@ sub dnssec11 {
                         my $ok =
                           $sig->verify_time( [ values %dnskey ], [ values %dnskey ], $dnskey_p->timestamp, $msg );
                         if ( $ok ) {
-                            return info( DELEGATION_SIGNED => { keytag => $tag } );
+                            $pass = $tag;
                         }
                         else {
-                            push @results,
-                              info( DELEGATION_NOT_SIGNED => { keytag => $tag, reason => "signature: $msg" } );
+                            push @fail, "signature: $msg" ;
                         }
                     }
                     else {
-                        push @results, info( DELEGATION_NOT_SIGNED => { keytag => $tag, reason => 'no_signature' } );
+                        push @fail, 'no_signature';
                     }
                 }
                 else {
-                    push @results, info( DELEGATION_NOT_SIGNED => { keytag => $tag, reason => 'dnskey_no_match' } );
+                    push @fail, 'dnskey_no_match';
                 }
             } ## end if ( $key )
             else {
-                push @results, info( DELEGATION_NOT_SIGNED => { keytag => $tag, reason => 'no_dnskey' } );
+                push @fail, 'no_dnskey';
             }
         } ## end foreach my $tag ( keys %ds )
     } ## end if ( scalar( keys %ds ...))
     else {
-        push @results, info( DELEGATION_NOT_SIGNED => { keytag => 'none', reason => 'no_ds' } );
+        push @fail, 'no_ds';
+    }
+
+    if ($pass) {
+        push @results, info( DELEGATION_SIGNED => { keytag => $pass } )
+    } else {
+        push @results, info( DELEGATION_NOT_SIGNED => { keytag => 'info', reason => join(';', @fail) } )
     }
 
     return @results;
